@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KSMTP_SESSIONUIPROXY_H
-#define KSMTP_SESSIONUIPROXY_H
+#pragma once
 
 #include "ksmtp_export.h"
 
@@ -50,5 +49,3 @@ public:
     virtual bool ignoreSslError(const KSslErrorUiData &errorData) = 0;
 };
 }
-
-#endif
